@@ -35,6 +35,9 @@ will always be -1.
 NON_WEAR_THRESHOLD = 3  # H
 NON_WEAR_PREDICTION_FLAG = -1
 
+START_TIME_IDX = 0
+END_TIME_IDX = -1
+
 
 def load_model(model_path, force_download=False):
     """ Load trained model. Download if not exists. """
@@ -42,7 +45,7 @@ def load_model(model_path, force_download=False):
     pth = pathlib.Path(model_path)
 
     if force_download or not pth.exists():
-        url = "https://github.com/OxWearables/asleep/releases/download/0.3.1/ssl.joblib.lzma"
+        url = "https://github.com/OxWearables/asleep/releases/download/0.4.12/ssl.joblib.lzma"
 
         print(f"Downloading {url}...")
 
@@ -69,8 +72,8 @@ def get_parsed_data(raw_data_path, info_data_path, resample_hz, args):
         data = data.reset_index()
 
         # apply time shift
-        start_time = pd.to_datetime(info['StartTime'])
-        end_time = pd.to_datetime(info['EndTime'])
+        start_time = pd.to_datetime(info.get("StartTime", data["time"].iloc[START_TIME_IDX]))
+        end_time = pd.to_datetime(info.get("EndTime", data["time"].iloc[END_TIME_IDX]))
         info['StartTime'] = start_time + datetime.timedelta(hours=time_shift)
         info['EndTime'] = end_time + datetime.timedelta(hours=time_shift)
         info['StartTime'] = info['StartTime'].strftime('%Y-%m-%d %H:%M:%S')
@@ -262,7 +265,7 @@ def main():
         help="Min wear time in hours to be eligible for summary statistics "
              "computation. The sleepnet paper uses 22",
         type=int,
-        default=0)
+        default=22)
     parser.add_argument(
         "--time_shift",
         type=str,
@@ -310,23 +313,30 @@ def main():
     (binary_y, all_sleep_wins_df, sleep_wins_long_per_day_df, master_acc,
      master_npids) = get_sleep_windows(data2model, times, non_wear, args)
 
-    y_pred, test_pids = start_sleep_net(
-        master_acc, master_npids, args.outdir,
-        args.model_weight_path, local_repo_path=args.local_repo_path,
-        device_id=args.pytorch_device)
-    sleepnet_output = binary_y
+    if len(master_npids) <= 0:
+        print("No sleep windows >30 mins detected. Exiting...")
+        print("Non-wear time has been written to %s" % non_wear_path)
+        print("Current sleep classification has been written to %s" %
+              os.path.join(args.outdir, 'ssl_sleep.npy'))
+        exit()
+    else:
+        y_pred, test_pids = start_sleep_net(
+            master_acc, master_npids, args.outdir,
+            args.model_weight_path, local_repo_path=args.local_repo_path,
+            device_id=args.pytorch_device)
+        sleepnet_output = binary_y
 
-    for block_id in range(len(all_sleep_wins_df)):
-        start_t = all_sleep_wins_df.iloc[block_id]['start']
-        end_t = all_sleep_wins_df.iloc[block_id]['end']
+        for block_id in range(len(all_sleep_wins_df)):
+            start_t = all_sleep_wins_df.iloc[block_id]['start']
+            end_t = all_sleep_wins_df.iloc[block_id]['end']
 
-        time_filter = (times >= start_t) & (times < end_t)
+            time_filter = (times >= start_t) & (times < end_t)
 
-        # get the corresponding sleepnet predictions
-        sleepnet_pred = y_pred[test_pids == block_id]
+            # get the corresponding sleepnet predictions
+            sleepnet_pred = y_pred[test_pids == block_id]
 
-        # fill the sleepnet predictions back to the original dataframe
-        sleepnet_output[time_filter] = sleepnet_pred
+            # fill the sleepnet predictions back to the original dataframe
+            sleepnet_output[time_filter] = sleepnet_pred
 
     # 3. Skip this step if predictions already exist
     # Output pandas dataframe
