@@ -64,16 +64,17 @@ def fill_sleep_block_gaps(sleep_block_idxes, counter):
 
 def count_sleep_block_gap(sleep_block_idxes, counter, epoch_length=30):
     # epoch_length sec
+    # find the gap between sleep blocks that are less than 30 mins apart
     gap2fill = []
     if len(sleep_block_idxes) > 1:
         first_block = counter[sleep_block_idxes[0]]
         end_of_block_idx = first_block[IDX_POS] + first_block[LEN_POS]
-        min_one_hour_block_diff = 60 * 60 / epoch_length
+        min_30_mins_block_diff = 30 * 60 / epoch_length
         i = 1
         while i < len(sleep_block_idxes):
             current_block = counter[sleep_block_idxes[i]]
             dist2pre_block = current_block[IDX_POS] - end_of_block_idx
-            if dist2pre_block <= min_one_hour_block_diff:
+            if dist2pre_block <= min_30_mins_block_diff:
                 gap2fill.append(i - 1)
             end_of_block_idx = current_block[IDX_POS] + current_block[LEN_POS]
             i += 1
@@ -98,6 +99,7 @@ def find_sleep_windows(sleep_blocks):
             if current_start_master_idx != -1:
                 all_sleep_blocks.append(
                     [current_start_master_idx, current_end_master_idx])
+                current_start_master_idx = -1
             continue
         pre_class = win[CLASS_POS]
 
@@ -271,6 +273,10 @@ def get_day_intervals(start_date, end_date, date_format):
     my_day_start = start_date.replace(
         hour=12, minute=0, second=0, microsecond=0)
 
+    # if the start date is before 12:00 noon, then the interval start is 24 hours prior
+    if start_date.hour < 12:
+        my_day_start = my_day_start - timedelta(hours=24)
+
     while my_day_end < end_date:
         my_day_end = my_day_start + timedelta(hours=23, minutes=59, seconds=59)
         day_intervals.append([my_day_start, my_day_end])
